#!/usr/bin/perl
# ver 21 Nov 1997 (fixed star counting problem and duplicate param name problem)
# javcnvt.pl
#
# This file was converted from BASIC to PERL on 11 April 97
#
# This program is a conversion utility for the 440 Netware Class and my
# WWW site.  It takes a set of quiz questions (see the .txt files for the
# format) and converts them to a java program which you must
# compile.
#
# The program expects my skeleton Java class (skeleton.jav), a text file
# with the extension .txt and an HTML skeleton so it can
# make an HTML that will call the Java file.
#
# INPUT FILES:
#       skeleton.jav
#       skeleton.htm
#       test.txt  (substitute a more explanatory name for your text file)
#                 (since you will get the following as output)
# OUTPUT FILES:
#       test.html
#       test.java
#

while ($prompt ne "Y")
{
  printf  "Input file (do not use an extension - it assumed to be .txt) ";
  $f1 = <STDIN>;
  chop($f1);
  printf "You entered $f1.txt, is this right? (y/n) ";
  $prompt = uc(<STDIN>);
  chop($prompt);
}

open (TEXTFILE,"$f1.txt");
open (TEMPFILE,">$f1.tmp");
open (JAVAFILE,">$f1.java");
open (HTMLSKELETON,"skeleton.htm");
open (HTML,">$f1.html");

# First set up the conversion to a Java method and save it in tempfile

$x=1;

printf TEMPFILE "   public void setuptext()\n";
printf TEMPFILE "   {\n";


$stars = 0;

while(<TEXTFILE>)
{
    #
    #if we find a back slash ("\") then we need to put another one right
    #next to it or else Java (which is like C/C++) will error out when
    #it tries to compile the code.  The following code does the job for
    #the case of ONE backslash per line
    #
   
    s/\\/\\\\/ig;
    # the perl version does global replacement .. not just one

    # double quotes aren't allowed either, so convert them to single quotes
   
    s/\"/\'/ig;    # again, perl does it globally

    #
    #if we find a .bmp file, then we need to convert it to a .jpg or .gif
    #THIS PROGRAM DOES NOT CONVERT THE FILES THEMSELVES - IT JUST CHANGES
    #THE REFERENCE FILENAME. In addition, it also assumes you used lower
    #case for the filename extension.  It converts the extension to type
    #gif.  Alter the appropriate lines to make it a jpg.
    #

    s/bmp/gif/ig;   # this line doesn't care whether it's upper or lower case

    # we count the number of questions in the file here.  we will use it
    # when we convert the Java skeleton to a real Java class

    if(m/^\*/)
      {
        $stars++;
      }

    chop();
    printf TEMPFILE "     questions[$x] = \"$_\";\n";

    $x++;

 }
printf TEMPFILE "     questions[$x] = \"eof\";\n";
printf TEMPFILE "   }\n";
close(TEMPFILE);
close(TEXTFILE);

# now make a java program using the java skeleton and the java method

open(TEMPFILE,"$f1.tmp");
open(SKELJAVA,"skeleton.jav");

$flag=0;

while(<SKELJAVA>)
 {
  $flag = 0;
 
  # change the name of the Java class to the current file prefix
  # (or else it won't compile)
 
  if(m/public class skeleton/)
   {
     print JAVAFILE "public class ".$f1." extends Applet";
     $flag=1;
   }

  #substitute the right number of questions so the Java methods
  #can find them all without getting null pointers or array bounds problems

  if(m/maxquestions = /)
    {
      print JAVAFILE "     double maxquestions = $stars.0;\n";
      $flag=1;
    }

  if(m/maxques = /)
    {
      print JAVAFILE "     int maxques = $stars;\n";
      $flag=1;
    }

   if($flag<1)
     {
       print JAVAFILE $_;
     }
 }

while (<TEMPFILE>)
 {
   print JAVAFILE $_;
 }
 print JAVAFILE "}\n";
 close(JAVAFILE);
 close(TEMPFILE);
 close(SKELJAVA);


# now make the html file


while (<HTMLSKELETON>)
{

  # find the place where we call the Java class file and change the
  # name to our name.

   if(m/skeleton.class/)
     {
      printf HTML "\n\<applet code = \"$f1.class\" width=500 height=300 \>";
     }
   if((m/param name/) && (m/caption/))
     {
      printf HTML "\n\<param name = \"caption\" value = \"$f1\" \>";
     }
   if((!m/param name/) && (!m/skeleton.class/))
      {
       printf HTML $_;
      }
   if((m/param name/) && (m/host/))
     {
      printf HTML $_;
      printf HTML "\n";
     }

}
close(HTML);
close(HTMLSKELETON);

print "\nYour files are all made.  Compile $f1.java with your java ";
print "\ncompiler and you are in business.";

#END

